@@ -96,7 +96,7 @@ def parseHeader(headerfile, classname):
 			line.startswith("*") or 
 			line.startswith(classname) or
 			line.startswith("class") or
-			line.startswith("Q_OBJECT") or
+			line.startswith("TQ_OBJECT") or
 			line.startswith("#") or
 			line.startswith("}") or
 			line.startswith("public Q_SLOTS:") or
