@@ -28,7 +28,7 @@
  */
 class KisFilterConfigWidget : public TQWidget {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
