@@ -75,7 +75,7 @@ class KRITACORE_EXPORT KisPaintDevice
     , public TDEShared
 {
 
-        Q_OBJECT
+        TQ_OBJECT
   
 
 public:
