@@ -65,7 +65,7 @@ class KisDoubleClickEvent;
 class KisCanvasWidgetPainter;
 
 class KisCanvasWidget : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -282,7 +282,7 @@ protected:
 };
 
 class KisCanvas : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -362,7 +362,7 @@ protected:
     void setUpdatesEnabled(bool updatesEnabled);
     bool isUpdatesEnabled() const;
 
-    void setFocusPolicy(TQ_FocusPolicy focusPolicy);
+    void setFocusPolicy(TQWidget::FocusPolicy focusPolicy);
 
     const TQCursor& cursor() const;
     void setCursor(const TQCursor& cursor);
