@@ -307,15 +307,15 @@ void KoBirdEyePanel::updateVisibleArea()
 
 bool KoBirdEyePanel::eventFilter(TQObject* o, TQEvent* ev)
 {
-    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_page->view) && ev->type() == TQEvent::Resize) {
+    if (o == m_page->view && ev->type() == TQEvent::Resize) {
         resizeViewEvent(TQT_TQRESIZEEVENT(ev)->size());
     }
 
-    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_page->view) && ev->type() == TQEvent::Paint) {
+    if (o == m_page->view && ev->type() == TQEvent::Paint) {
         paintViewEvent(TQT_TQPAINTEVENT(ev));
     }
 
-    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_page->view) && ev->type() == TQEvent::MouseMove) {
+    if (o == m_page->view && ev->type() == TQEvent::MouseMove) {
 
         TQMouseEvent* me = (TQMouseEvent*)ev;
         TQPoint thumbnailPos = viewToThumbnail(me->pos());
@@ -329,7 +329,7 @@ bool KoBirdEyePanel::eventFilter(TQObject* o, TQEvent* ev)
         return true;
     }
 
-    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_page->view) && ev->type() == TQEvent::MouseButtonPress) {
+    if (o == m_page->view && ev->type() == TQEvent::MouseButtonPress) {
 
         TQMouseEvent* me = (TQMouseEvent*)ev;
         TQPoint thumbnailPos = viewToThumbnail(me->pos());
@@ -341,7 +341,7 @@ bool KoBirdEyePanel::eventFilter(TQObject* o, TQEvent* ev)
         return true;
     }
 
-    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_page->view) && ev->type() == TQEvent::MouseButtonRelease) {
+    if (o == m_page->view && ev->type() == TQEvent::MouseButtonRelease) {
 
         TQMouseEvent* me = (TQMouseEvent*)ev;
 
@@ -403,7 +403,7 @@ void KoBirdEyePanel::handleMouseMove(TQPoint p)
         break;
     default:
     case DragHandleNone:
-        if (TQT_TQRECT_OBJECT(m_thumbnail.rect()).contains(p)) {
+        if (m_thumbnail.rect().contains(p)) {
             cursor = TQt::PointingHandCursor;
         } else {
             cursor = TQt::arrowCursor;
@@ -462,7 +462,7 @@ void KoBirdEyePanel::handleMousePress(TQPoint p)
         enumDragHandle dragHandle = dragHandleAt(p);
 
         if (dragHandle == DragHandleNone) {
-            if (TQT_TQRECT_OBJECT(m_thumbnail.rect()).contains(p)) {
+            if (m_thumbnail.rect().contains(p)) {
     
                 // Snap visible area centre to p and begin a centre drag.
     
