@@ -179,7 +179,7 @@ public:
         if( !m_img.isNull() )
         {
             if( m_img.width() > MAX_SIZE || m_img.height() > MAX_SIZE )
-                m_img = m_img.scale( MAX_SIZE, MAX_SIZE, TQ_ScaleMin );
+                m_img = m_img.scale( MAX_SIZE, MAX_SIZE, TQImage::ScaleMin );
             int y = 0;
             if( m_img.height() < text.height() )
                 y = text.height()/2 - m_img.height()/2;
@@ -1128,7 +1128,7 @@ void LayerItem::drawPreview( TQPainter *p, const TQColorGroup &/*cg*/, const TQR
     if( d->previewChanged || r.size() != d->previewSize )
     {      //TODO handle width() != height()
         const int size = kMin( r.width(), kMax( previewImage()->width(), previewImage()->height() ) );
-        const TQImage i = previewImage()->smoothScale( size, size, TQ_ScaleMin );
+        const TQImage i = previewImage()->smoothScale( size, size, TQImage::ScaleMin );
         d->scaledPreview.convertFromImage( i );
         d->previewOffset.setX( r.width()/2 - i.width()/2 );
         d->previewOffset.setY( r.height()/2 - i.height()/2 );
