@@ -31,7 +31,7 @@
 class TQPainter;
 
 class VRuler : public TQFrame {
-    Q_OBJECT
+    TQ_OBJECT
   
     typedef TQFrame super;
 
