@@ -40,6 +40,7 @@
 #include <tqtextstream.h>
 #include <tqsimplerichtext.h>
 #include <tqdom.h>
+#include <tqvaluevector.h>
 #include <limits.h>
 
 #include <math.h>
@@ -54,11 +55,6 @@
 #include "KDChartAxisParams.h"
 #include "KDChartPropertySet.h"
 
-#if COMPAT_TQT_VERSION >= 0x030000
-#include <tqvaluevector.h>
-#else
-#include <tqarray.h>
-#endif
 
 /** \file KDChartParams.h
     \brief Header for all common chart parameters.
@@ -139,7 +135,7 @@ private:
 class KDCHART_EXPORT KDChartParams : public TQObject
 {
 
-    Q_OBJECT
+    TQ_OBJECT
   
     TQ_ENUMS(ChartType)
     TQ_ENUMS(SourceMode)
@@ -226,7 +222,7 @@ public:
 // MOC_SKIP_BEGIN
     class KDCHART_EXPORT KDChartFrameSettings
     {
-        // Q_OBJECT
+        // TQ_OBJECT
         // 
     public:
         KDChartFrameSettings();
@@ -2097,11 +2093,7 @@ public slots:
                        uint& chart ) const;
 
 public:
-#if COMPAT_TQT_VERSION >= 0x030000
     typedef TQValueVector<uint> AxesArray;
-#else
-    typedef TQArray<uint> AxesArray;
-#endif
 
 public slots:
     bool chartAxes( uint chart, uint& cnt, AxesArray& axes ) const;
