@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
    */
 
@@ -90,13 +90,7 @@ void KDChartPolarPainter::paintData( TQPainter* painter,
     //
 
     const TQWMatrix & world = painter->worldMatrix();
-    ourClipRect =
-#if COMPAT_TQT_VERSION >= 0x030000
-        world.mapRect( ourClipRect );
-#else
-    world.map( ourClipRect );
-#endif
-
+    ourClipRect = world.mapRect( ourClipRect );
     painter->setClipRect( ourClipRect );
 
 
@@ -256,11 +250,11 @@ void KDChartPolarPainter::paintData( TQPainter* painter,
                 dtDeltaScale );
                 labelTexts = ( TQStringList* ) paraCircular.axisLabelTexts();
         if( paraCircular.axisLabelsVisible() ) {
-//qDebug("\nnTxtHeight: "+TQString::number(nTxtHeight));
+//tqDebug("\nnTxtHeight: "+TQString::number(nTxtHeight));
             // calculate font size
             actFont = paraCircular.axisLabelsFont();
             if ( paraCircular.axisLabelsFontUseRelSize() ) {
-//qDebug("paraCircular.axisLabelsFontUseRelSize() is TRUE");
+//tqDebug("paraCircular.axisLabelsFontUseRelSize() is TRUE");
                 actFont.setPointSizeFloat( nTxtHeight );
             }
             TQFontMetrics fm( actFont );
