@@ -100,7 +100,7 @@ void KexiDialogBase::addView(KexiViewBase *view, int mode)
 //	addActionProxyChild( view );
 
 	//set focus proxy inside this view
-	TQWidget *ch = TQT_TQWIDGET(view->child( 0, TQWIDGET_OBJECT_NAME_STRING, false ));
+	TQWidget *ch = TQT_TQWIDGET(view->child( 0, "TQWidget", false ));
 	if (ch)
 		view->setFocusProxy(ch);
 
