@@ -112,7 +112,7 @@ void KexiSharedActionHost::updateActionAvailable(const char *action_name, bool a
 	if (!d)
 		return; //sanity
 	TQWidget *fw = d->mainWin->focusWidget();
-	while (fw && TQT_BASE_OBJECT(obj)!=TQT_BASE_OBJECT(fw))
+	while (fw && obj!=fw)
 		fw = fw->parentWidget();
 	if (!fw)
 		return;
