@@ -212,7 +212,7 @@ bool KexiViewBase::removeDataBlock( const TQString& dataID )
 
 bool KexiViewBase::eventFilter( TQObject *o, TQEvent *e )
 {
-	if (e->type()==TQEvent::FocusIn || e->type()==TQEvent::FocusOut) {// && o->inherits(TQWIDGET_OBJECT_NAME_STRING)) {
+	if (e->type()==TQEvent::FocusIn || e->type()==TQEvent::FocusOut) {// && o->inherits("TQWidget")) {
 //		//hp==true if currently focused widget is a child of this table view
 //		const bool hp = Kexi::hasParent( static_cast<TQWidget*>(o), focusWidget());
 //		kexidbg << "KexiViewBase::eventFilter(): " << o->name() << " " << e->type() << endl;
