@@ -61,7 +61,7 @@ EventEater::eventFilter(TQObject *, TQEvent *ev)
 
 	// When the user click the empty part of tab bar, only MouseReleaseEvent is sent,
 	// we need to simulate the Press event
-	if(ev->type() == TQEvent::MouseButtonRelease && m_widget->inherits(TQTABWIDGET_OBJECT_NAME_STRING))
+	if(ev->type() == TQEvent::MouseButtonRelease && m_widget->inherits("TQTabWidget"))
 	{
 		TQMouseEvent *mev = TQT_TQMOUSEEVENT(ev);
 		if(mev->button() == Qt::LeftButton)
@@ -225,7 +225,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 					m_state = DrawingSelectionRect;
 			}
 			else {
-				if(s->inherits(TQTABWIDGET_OBJECT_NAME_STRING)) // to allow changing page by clicking tab
+				if(s->inherits("TQTabWidget")) // to allow changing page by clicking tab
 					return false;
 			}
 
@@ -267,7 +267,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 				if(!tree || !tree->widget())
 					return true;
 
-				if(m_form->formWidget() && (TQT_BASE_OBJECT(tree->widget()) != TQT_BASE_OBJECT(s)))
+				if(m_form->formWidget() && (tree->widget() != s))
 					m_form->formWidget()->highlightWidgets(tree->widget(), TQT_TQWIDGET(s));
 			}
 			else if(m_insertBegin!=TQPoint(-1,-1) && s == m_container && !m_toplevel && (mev->state() != ControlButton) && !FormManager::self()->isCreatingConnection()) // draw the selection rect
@@ -299,7 +299,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
 			{
 				if(!m_toplevel && m_moving == m_container) // no effect for form
 					return false;
-				if((!m_moving) || (!m_moving->parentWidget()))// || (m_moving->parentWidget()->inherits(TQWIDGETSTACK_OBJECT_NAME_STRING)))
+				if((!m_moving) || (!m_moving->parentWidget()))// || (m_moving->parentWidget()->inherits("TQWidgetStack")))
 						return true;
 
 				moveSelectedWidgetsBy(mev->x() - m_grab.x(), mev->y() - m_grab.y());
@@ -1107,13 +1107,13 @@ Container::moveSelectedWidgetsBy(int realdx, int realdy, TQMouseEvent *mev)
 
 	for(TQWidget *w = m_form->selectedWidgets()->first(); w; w = m_form->selectedWidgets()->next())
 	{
-		if(!w || !w->parent() || w->parent()->inherits(TQTABWIDGET_OBJECT_NAME_STRING) || w->parent()->inherits(TQWIDGETSTACK_OBJECT_NAME_STRING))
+		if(!w || !w->parent() || w->parent()->inherits("TQTabWidget") || w->parent()->inherits("TQWidgetStack"))
 			continue;
 
-		if(w->parentWidget() && w->parentWidget()->isA(TQWIDGETSTACK_OBJECT_NAME_STRING))
+		if(w->parentWidget() && w->parentWidget()->isA("TQWidgetStack"))
 		{
 			w = w->parentWidget(); // widget is WidgetStack page
-			if(w->parentWidget() && w->parentWidget()->inherits(TQTABWIDGET_OBJECT_NAME_STRING)) // widget is tabwidget page
+			if(w->parentWidget() && w->parentWidget()->inherits("TQTabWidget")) // widget is tabwidget page
 				w = w->parentWidget();
 		}
 
@@ -1133,13 +1133,13 @@ Container::moveSelectedWidgetsBy(int realdx, int realdy, TQMouseEvent *mev)
 	for(TQWidget *w = m_form->selectedWidgets()->first(); w; w = m_form->selectedWidgets()->next())
 	{
 		// Don't move tab widget pages (or widget stack pages)
-		if(!w || !w->parent() || w->parent()->inherits(TQTABWIDGET_OBJECT_NAME_STRING) || w->parent()->inherits(TQWIDGETSTACK_OBJECT_NAME_STRING))
+		if(!w || !w->parent() || w->parent()->inherits("TQTabWidget") || w->parent()->inherits("TQWidgetStack"))
 			continue;
 
-		if(w->parentWidget() && w->parentWidget()->isA(TQWIDGETSTACK_OBJECT_NAME_STRING))
+		if(w->parentWidget() && w->parentWidget()->isA("TQWidgetStack"))
 		{
 			w = w->parentWidget(); // widget is WidgetStack page
-			if(w->parentWidget() && w->parentWidget()->inherits(TQTABWIDGET_OBJECT_NAME_STRING)) // widget is tabwidget page
+			if(w->parentWidget() && w->parentWidget()->inherits("TQTabWidget")) // widget is tabwidget page
 				w = w->parentWidget();
 		}
 
