@@ -268,10 +268,10 @@ Form::setSelectedWidget(TQWidget *w, bool add, bool dontRaise, bool moreWillBeSe
 	emitActionSignals(false);
 
 	// WidgetStack and TabWidget pages widgets shouldn't have resize handles, but their parent
-	if(!FormManager::self()->isTopLevel(w) && w->parentWidget() && w->parentWidget()->isA(TQWIDGETSTACK_OBJECT_NAME_STRING))
+	if(!FormManager::self()->isTopLevel(w) && w->parentWidget() && w->parentWidget()->isA("TQWidgetStack"))
 	{
 		w = w->parentWidget();
-		if(w->parentWidget() && w->parentWidget()->inherits(TQTABWIDGET_OBJECT_NAME_STRING))
+		if(w->parentWidget() && w->parentWidget()->inherits("TQTabWidget"))
 			w = w->parentWidget();
 	}
 
@@ -457,14 +457,14 @@ Form::addWidgetToTabStops(ObjectTreeItem *it)
 	TQWidget *w = it->widget();
 	if(!w)
 		return;
-	if(!(w->focusPolicy() & TQ_TabFocus))
+	if(!(w->focusPolicy() & TQWidget::TabFocus))
 	{
 		TQObjectList clo = w->childrenListObject();
 		if (clo.isEmpty())
 			return;
 		// For composed widgets, we check if one of the child can have focus
 		for(TQObjectListIterator chIt(clo); chIt.current(); ++chIt) {
-			if(chIt.current()->isWidgetType()) {//TQ_TabFocus flag will be checked later!
+			if(chIt.current()->isWidgetType()) {//TQWidget::TabFocus flag will be checked later!
 				if(d->tabstops.findRef(it) == -1) {
 					d->tabstops.append(it);
 					return;
@@ -480,7 +480,7 @@ void
 Form::updateTabStopsOrder()
 {
 	for (ObjectTreeListIterator it(d->tabstops);it.current();) {
-		if(!(it.current()->widget()->focusPolicy() & TQ_TabFocus)) {
+		if(!(it.current()->widget()->focusPolicy() & TQWidget::TabFocus)) {
 			kexidbg << "Form::updateTabStopsOrder(): widget removed because has no TabFocus: " << it.current()->widget()->name() << endl;
 			d->tabstops.remove( it.current() );
 		}
