@@ -177,7 +177,7 @@ FormIO::saveFormToDom(Form *form, TQDomDocument &domDoc)
 	// We create the top class element
 	TQDomElement baseClass = domDoc.createElement("class");
 	uiElement.appendChild(baseClass);
-	TQDomText baseClassV = domDoc.createTextNode(TQWIDGET_OBJECT_NAME_STRING);
+	TQDomText baseClassV = domDoc.createTextNode("TQWidget");
 	baseClass.appendChild(baseClassV);
 
 	// Save the toplevel widgets, and so the whole Form
@@ -771,10 +771,10 @@ FormIO::readPropertyValue(TQDomNode node, TQObject *obj, const TQString &name)
 	else if(type == "bool")
 	{
 		if(text == "true")
-			return TQVariant(true, 3);
+			return TQVariant(true);
 		else if(text == "false")
-			return TQVariant(false, 3);
-		return TQVariant(text.toInt(), 3);
+			return TQVariant(false);
+		return TQVariant(text.toInt());
 	}
 	else if(type == "number")
 	{
@@ -952,11 +952,11 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
 	}
 
 	if(!item->parent()) // Toplevel widget
-		tclass.setAttribute("class", TQWIDGET_OBJECT_NAME_STRING);
-	// For compatibility, HBox, VBox and Grid are saved as TQLAYOUTWIDGET_OBJECT_NAME_STRING
+		tclass.setAttribute("class", "TQWidget");
+	// For compatibility, HBox, VBox and Grid are saved as "TQLayoutWidget"
 	else if(item->widget()->isA("HBox") || item->widget()->isA("VBox") || item->widget()->isA("Grid")
 			|| item->widget()->isA("HFlow") || item->widget()->isA("VFlow"))
-		tclass.setAttribute("class", TQLAYOUTWIDGET_OBJECT_NAME_STRING);
+		tclass.setAttribute("class", "TQLayoutWidget");
 	else if(item->widget()->isA("CustomWidget"))
 		tclass.setAttribute("class", item->className());
 	else // Normal widgets
@@ -983,13 +983,13 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
 		savePropertyValue(tclass, domDoc, "geometry", item->widget()->property("geometry"), item->widget());
 
 	// Save the buddy widget for a label
-	if(item->widget()->inherits(TQLABEL_OBJECT_NAME_STRING) && ((TQLabel*)item->widget())->buddy())
+	if(item->widget()->inherits("TQLabel") && ((TQLabel*)item->widget())->buddy())
 		savePropertyElement(tclass, domDoc, "property", "buddy", ((TQLabel*)item->widget())->buddy()->name());
 
 	// We save every property in the modifProp list of the ObjectTreeItem
-	TQVariantMap *map = new TQVariantMap( *(item->modifiedProperties()) );
-	TQMap<TQString,TQVariant>::ConstIterator endIt = map->constEnd();
-	for(TQMap<TQString,TQVariant>::ConstIterator it = map->constBegin(); it != endIt; ++it)
+	TQStringVariantMap *map = new TQStringVariantMap( *(item->modifiedProperties()) );
+	TQStringVariantMap::ConstIterator endIt = map->constEnd();
+	for(TQStringVariantMap::ConstIterator it = map->constBegin(); it != endIt; ++it)
 	{
 		const TQCString name( it.key().latin1() );
 		if(name == "hAlign" || name == "vAlign" || name == "wordbreak" || name == "alignment") {
@@ -1076,7 +1076,7 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
 
 			// save some special properties
 			savePropertyElement(layout, domDoc, "property", "customLayout", Container::layoutTypeToString(item->container()->layoutType()) );
-			savePropertyElement(layout, domDoc, "property", "justify", TQVariant(static_cast<KexiFlowLayout*>(item->container()->layout())->isJustified(), 3) );
+			savePropertyElement(layout, domDoc, "property", "justify", TQVariant(static_cast<KexiFlowLayout*>(item->container()->layout())->isJustified()) );
 
 			// fill the widget's grid info, ie just simulate grid layout
 			item->container()->createGridLayout(true);
@@ -1141,7 +1141,7 @@ FormIO::loadWidget(Container *container, const TQDomElement &el, TQWidget *paren
 	// We translate some name (for compatibility)
 	if(el.tagName() == "spacer")
 		classname = "Spring";
-	else if(el.attribute("class") == TQLAYOUTWIDGET_OBJECT_NAME_STRING)
+	else if(el.attribute("class") == "TQLayoutWidget")
 	{
 		for(TQDomNode n = el.firstChild(); !n.isNull(); n = n.nextSibling())
 		{
