@@ -291,7 +291,7 @@ FormManager::insertWidget(const TQCString &classname)
 //		form->d->cursors = new TQMap<TQString, TQCursor>();
 		if (form->toplevelContainer())
 			form->widget()->setCursor(TQCursor(CrossCursor));
-		TQObjectList *l = form->widget()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+		TQObjectList *l = form->widget()->queryList( "TQWidget" );
 		for(TQObject *o = l->first(); o; o = l->next())
 		{
 			if( ((TQWidget*)o)->ownCursor() )
@@ -322,7 +322,7 @@ FormManager::stopInsert()
 	for(form = m_forms.first(); form; form = m_forms.next())
 	{
 		form->widget()->unsetCursor();
-		TQObjectList *l = form->widget()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+		TQObjectList *l = form->widget()->queryList( "TQWidget" );
 		for(TQObject *o = l->first(); o; o = l->next())
 		{
 			TQT_TQWIDGET(o)->unsetCursor();
@@ -373,7 +373,7 @@ FormManager::startCreatingConnection()
 			form->widget()->setCursor(TQCursor(PointingHandCursor));
 			form->widget()->setMouseTracking(true);
 		}
-		TQObjectList *l = form->widget()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+		TQObjectList *l = form->widget()->queryList( "TQWidget" );
 		for(TQObject *o = l->first(); o; o = l->next())
 		{
 			TQWidget *w = TQT_TQWIDGET(o);
@@ -432,7 +432,7 @@ FormManager::stopCreatingConnection()
 	{
 		form->widget()->unsetCursor();
 		form->widget()->setMouseTracking(false);
-		TQObjectList *l = form->widget()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+		TQObjectList *l = form->widget()->queryList( "TQWidget" );
 		for(TQObject *o = l->first(); o; o = l->next())
 		{
 			TQWidget *w = (TQWidget*)o;
@@ -898,7 +898,7 @@ FormManager::createContextMenu(TQWidget *w, Container *container, bool popupAtCu
 	separatorNeeded = true;
 
 	// We create the buddy menu
-	if(!multiple && w->inherits(TQLABEL_OBJECT_NAME_STRING) && ((TQLabel*)w)->text().contains("&") && (((TQLabel*)w)->textFormat() != RichText))
+	if(!multiple && w->inherits("TQLabel") && ((TQLabel*)w)->text().contains("&") && (((TQLabel*)w)->textFormat() != RichText))
 	{
 		if (separatorNeeded)
 			m_popup->insertSeparator();
@@ -1210,7 +1210,7 @@ FormManager::slotStyle()
 	TQString style = m_style->currentText();
 	activeForm()->widget()->setStyle( style );
 
-	TQObjectList *l = activeForm()->widget()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+	TQObjectList *l = activeForm()->widget()->queryList( "TQWidget" );
 	for(TQObject *o = l->first(); o; o = l->next())
 		(TQT_TQWIDGET(o))->setStyle( style );
 	delete l;
