@@ -139,7 +139,7 @@ KFormDesignerKDevPart::KFormDesignerKDevPart(TQWidget *parent, const char *name,
 	m_inShell = (!args.grep("shell").isEmpty());
 
 	TQHBox *container = new TQHBox(parent, "kfd_container_widget");
-	container->setFocusPolicy(TQ_ClickFocus);
+	container->setFocusPolicy(TQWidget::ClickFocus);
 
 	m_workspace = new TQWorkspace(container, "kfd_workspace");
 	m_workspace->show();
@@ -538,7 +538,7 @@ KFormDesignerKDevPart::~KFormDesignerKDevPart()
 //repaint all children widgets
 static void repaintAll(TQWidget *w)
 {
-	TQObjectList *list = w->queryList(TQWIDGET_OBJECT_NAME_STRING);
+	TQObjectList *list = w->queryList("TQWidget");
 	TQObjectListIt it(*list);
 	for (TQObject *obj; (obj=it.current()); ++it ) {
 		static_cast<TQWidget*>(obj)->repaint();
