@@ -562,7 +562,7 @@ KFormDesignerPart::setRedoEnabled(bool enabled, const TQString &text)
 static void repaintAll(TQWidget *w)
 {
 	w->repaint();
-	TQObjectList *list = w->queryList(TQWIDGET_OBJECT_NAME_STRING);
+	TQObjectList *list = w->queryList("TQWidget");
 	TQObjectListIt it(*list);
 	for (TQObject *obj; (obj=it.current()); ++it ) {
 		static_cast<TQWidget*>(obj)->repaint();
