@@ -37,7 +37,7 @@ class Form;
  If the parent is found, \a prevPrev is set to a child of child of the parent, 
  what for TabWidget means the page widget. */
 template<class type>
-type* findParent(TQT_BASE_OBJECT_NAME* o, const char* className, TQObject* &prevPrev)
+type* findParent(TQObject* o, const char* className, TQObject* &prevPrev)
 {
 	if (!o || !className || className[0]=='\0')
 		return 0;
@@ -52,7 +52,7 @@ type* findParent(TQT_BASE_OBJECT_NAME* o, const char* className, TQObject* &prev
 //! A tab widget providing information about height of the tab bar.
 class KFORMEDITOR_EXPORT TabWidget : public TabWidgetBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		TabWidget(TQWidget *parent, const char *name) 
@@ -106,7 +106,7 @@ KFORMEDITOR_EXPORT void removeRecursiveEventFilter(TQObject *object, TQObject *c
 KFORMEDITOR_EXPORT void setRecursiveCursor(TQWidget *w, Form *form);
 
 /*! \return the size of \a w children. This can be used eg to get widget's sizeHint. */
-KFORMEDITOR_EXPORT TQSize getSizeFromChildren(TQWidget *widget, const char *inheritClass=TQWIDGET_OBJECT_NAME_STRING);
+KFORMEDITOR_EXPORT TQSize getSizeFromChildren(TQWidget *widget, const char *inheritClass="TQWidget");
 
 }
 
