@@ -431,7 +431,7 @@ WidgetFactory::resetEditor()
 		tree->eventEater()->setContainer(m_container);
 		if(m_widget) {// && !ed)
 			setRecursiveCursor(m_widget, m_container->form());
-			if (m_widget->inherits(TQLINEEDIT_OBJECT_NAME_STRING) || m_widget->inherits(TQTEXTEDIT_OBJECT_NAME_STRING)) { //fix weird behaviour
+			if (m_widget->inherits("TQLineEdit") || m_widget->inherits("TQTextEdit")) { //fix weird behaviour
 				m_widget->unsetCursor();
 				m_widget->setCursor(TQt::ArrowCursor);
 			}
