@@ -283,7 +283,7 @@ void KexiUtils::drawPixmap( TQPainter& p, int lineWidth, const TQRect& rect,
 	if (scaledContents) {
 		if (keepAspectRatio) {
 			TQImage img(pixmap.convertToImage());
-			img = img.smoothScale(w, h, TQ_ScaleMin);
+			img = img.smoothScale(w, h, TQImage::ScaleMin);
 			pos = rect.topLeft(); //0, 0);
 			if (img.width() < w) {
 				int hAlign = TQApplication::horizontalAlignment( alignment );
