@@ -192,7 +192,7 @@ KexiNewProjectWizard::KexiNewProjectWizard(KexiDBConnectionSet& conn_set,
 	m_project_selector = new KexiProjectSelectorWidget(
 		m_server_db_name->frm_dblist, "KexiProjectSelectorWidget", 0, false, false );
 	GLUE_WIDGET(m_project_selector, m_server_db_name->frm_dblist);
-	m_project_selector->setFocusPolicy(TQ_NoFocus);
+	m_project_selector->setFocusPolicy(TQWidget::NoFocus);
 	m_project_selector->setSelectable(false);
 
 	addPage(m_server_db_name, i18n("Select Project's Caption & Database Name"));
@@ -313,9 +313,9 @@ void KexiNewProjectWizard::accept()
 {
 	if (m_prjtype_sel->lv_types->currentItem()==d->lvi_file) {//FILE:
 		//check if new db file name is ok
-		kdDebug() << "********** TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())) " << TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->className() << endl;
+		kdDebug() << "********** sender() " << sender()->className() << endl;
 		if (sender()==finishButton()) { /*(only if signal does not come from filedialog)*/
-			kdDebug() << "********** TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))==finishButton() ********" << endl;
+			kdDebug() << "********** sender()==finishButton() ********" << endl;
 //			if (!m_conn_sel->m_fileDlg->checkURL()) {
 			if (!m_conn_sel->m_fileDlg->checkFileName()) {
 				return;
