@@ -176,7 +176,7 @@ KexiDBPasswordDialog::~KexiDBPasswordDialog()
 void KexiDBPasswordDialog::done(int r)
 {
 	if (r == TQDialog::Accepted) {
-		m_cdata->password = TQString::fromLatin1(password());
+		m_cdata->password = password();
 	}
 //	if (d->showConnectionDetailsExecuted || ret == TQDialog::Accepted) {
 /*			} else {
@@ -330,11 +330,11 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 		if (qstrcmp("--password",argv[i])==0
 			|| qstrcmp("-password",argv[i])==0)
 		{
-			TQCString pwd(argv[i+1]);
+			TQString pwd(argv[i+1]);
 			if (!pwd.isEmpty()) {
 				pwd.fill(' ');
 				pwd[0]='x';
-				qstrcpy(argv[i+1], (const char*)pwd);
+				qstrcpy(argv[i+1], (const char*)pwd.utf8().data());
 			}
 			break;
 		}
@@ -394,7 +394,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 			if (d->passwordDialog->showConnectionDetailsRequested() || ret == TQDialog::Accepted) {
 //				if ( ret == TQDialog::Accepted ) {
 		//		if (TQDialog::Accepted == KPasswordDialog::getPassword(pwd, msg)) {
-//moved				cdata.password = TQString(pwd);
+//moved				cdata.password = pwd;
 //				}
 			} else {
 				m_action = Exit;
