@@ -55,7 +55,7 @@ KexiStartupFileDialog::KexiStartupFileDialog(
 
 	//dirty hack to customize filedialog view:
 	{
-		TQObjectList *l = queryList( TQPUSHBUTTON_OBJECT_NAME_STRING );
+		TQObjectList *l = queryList( "TQPushButton" );
 		TQObjectListIt it( *l );
 		TQObject *obj;
 		while ( (obj = it.current()) != 0 ) {
@@ -65,7 +65,7 @@ KexiStartupFileDialog::KexiStartupFileDialog(
 		delete l;
 	}
 	{
-		TQObjectList *l = queryList(TQWIDGET_OBJECT_NAME_STRING);
+		TQObjectList *l = queryList("TQWidget");
 		TQObjectListIt it( *l );
 		TQObject *obj;
 		while ( (obj = it.current()) != 0 ) {
