@@ -262,10 +262,10 @@ KexiFormPart::generateForm(KexiDB::FieldList *list, TQDomDocument &domDoc)
 
 	TQDomElement baseClass = domDoc.createElement("class");
 	uiElement.appendChild(baseClass);
-	TQDomText baseClassV = domDoc.createTextNode(TQWIDGET_OBJECT_NAME_STRING);
+	TQDomText baseClassV = domDoc.createTextNode("TQWidget");
 	baseClass.appendChild(baseClassV);
 	TQDomElement baseWidget = domDoc.createElement("widget");
-	baseWidget.setAttribute("class", TQWIDGET_OBJECT_NAME_STRING);
+	baseWidget.setAttribute("class", "TQWidget");
 
 	int y=0;
 
@@ -273,7 +273,7 @@ KexiFormPart::generateForm(KexiDB::FieldList *list, TQDomDocument &domDoc)
 	{
 		TQDomElement lclass = domDoc.createElement("widget");
 		baseWidget.appendChild(lclass);
-		lclass.setAttribute("class", TQLABEL_OBJECT_NAME_STRING);
+		lclass.setAttribute("class", "TQLabel");
 		TQDomElement lNameProperty = domDoc.createElement("property");
 		lNameProperty.setAttribute("name", "name");
 		TQDomElement lType = domDoc.createElement("cstring");
@@ -400,7 +400,7 @@ void KexiFormPart::slotAutoTabStopsSet(KFormDesigner::Form *form, bool set)
 
 	KoProperty::Property &p = (*KFormDesigner::FormManager::self()->propertySet())["autoTabStops"];
 	if (!p.isNull())
-		p.setValue(TQVariant(set, 4));
+		p.setValue(TQVariant(set));
 }
 
 void KexiFormPart::slotAssignAction()
