@@ -29,7 +29,7 @@ KexiDBCheckBox::KexiDBCheckBox(const TQString &text, TQWidget *parent, const cha
  , m_tristateChanged(false)
  , m_tristate(TristateDefault)
 {
-	setFocusPolicy(TQ_StrongFocus);
+	setFocusPolicy(TQWidget::StrongFocus);
 	updateTristate();
 	connect(this, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(slotStateChanged(int)));
 }
@@ -44,8 +44,8 @@ void KexiDBCheckBox::setInvalidState( const TQString& displayText )
 	setState(NoChange);
 	m_invalidState = true;
 //! @todo move this to KexiDataItemInterface::setInvalidStateInternal() ?
-	if (focusPolicy() & TQ_TabFocus)
-		setFocusPolicy(TQ_ClickFocus);
+	if (focusPolicy() & TQWidget::TabFocus)
+		setFocusPolicy(TQWidget::ClickFocus);
 	setText(displayText);
 }
 
