@@ -91,7 +91,7 @@ void KexiDBDateTimeEdit::setInvalidState(const TQString & /*! @todo paint this t
 	m_invalidState = true;
 //! @todo move this to KexiDataItemInterface::setInvalidStateInternal() ?
 	if (focusPolicy() & TabFocus)
-		setFocusPolicy(TQ_ClickFocus);
+		setFocusPolicy(TQWidget::ClickFocus);
 }
 
 void
