@@ -128,7 +128,7 @@ KexiDataAwareObjectInterface* KexiDBForm::dataAwareObject() const { return d->da
 //repaint all children widgets
 static void repaintAll(TQWidget *w)
 {
-	TQObjectList *list = w->queryList(TQWIDGET_OBJECT_NAME_STRING);
+	TQObjectList *list = w->queryList("TQWidget");
 	TQObjectListIt it(*list);
 	for (TQObject *obj; (obj=it.current()); ++it ) {
 		TQT_TQWIDGET(obj)->repaint();
@@ -310,11 +310,11 @@ void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
 //	if (d->orderedFocusWidgets.isEmpty()) {
 		//generate a new list
 		for (KFormDesigner::ObjectTreeListIterator it(form->tabStopsIterator()); it.current(); ++it) {
-			if (it.current()->widget()->focusPolicy() & TQ_TabFocus) {
+			if (it.current()->widget()->focusPolicy() & TQWidget::TabFocus) {
 				//this widget has tab focus:
 				it.current()->widget()->installEventFilter(this);
 				//also filter events for data-aware children of this widget (i.e. KexiDBAutoField's editors)
-				TQObjectList *children = it.current()->widget()->queryList(TQWIDGET_OBJECT_NAME_STRING);
+				TQObjectList *children = it.current()->widget()->queryList("TQWidget");
 				for (TQObjectListIt childrenIt(*children); childrenIt.current(); ++childrenIt) {
 	//				if (dynamic_cast<KexiFormDataItemInterface*>(childrenIt.current())) {
 						kexipluginsdbg << "KexiDBForm::updateTabStopsOrder(): also adding '" 
@@ -368,7 +368,7 @@ void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
 void KexiDBForm::updateTabStopsOrder()
 {
 	for (TQPtrListIterator<TQWidget> it( d->orderedFocusWidgets ); it.current();) {
-		if (! (it.current()->focusPolicy() & TQ_TabFocus))
+		if (! (it.current()->focusPolicy() & TQWidget::TabFocus))
 			d->orderedFocusWidgets.remove( it.current() );
 		else
 			++it;
@@ -390,7 +390,7 @@ void KexiDBForm::updateReadOnlyFlags()
 bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 {
 	//kexipluginsdbg << e->type() << endl;
-	if (e->type()==TQEvent::Resize && TQT_BASE_OBJECT(watched) == TQT_BASE_OBJECT(this))
+	if (e->type()==TQEvent::Resize && watched == this)
 		kexipluginsdbg << "RESIZE" << endl;
 	if (e->type()==TQEvent::KeyPress) {
 		if (preview()) {
@@ -404,7 +404,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 
 			if (!tab && !backtab) {
 				//for buttons, left/up and right/down keys act like tab/backtab (see qbutton.cpp)
-				if (realWidget->inherits(TQBUTTON_OBJECT_NAME_STRING)) {
+				if (realWidget->inherits("TQButton")) {
 					if (ke->state() == Qt::NoButton && (key == TQt::Key_Right || key == TQt::Key_Down))
 						tab = true;
 					else if (ke->state() == Qt::NoButton && (key == TQt::Key_Left || key == TQt::Key_Up))
@@ -537,7 +537,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
 					KFormDesigner::TabWidget *tabWidgetFor_widgetToFocus 
 						= KFormDesigner::findParent<KFormDesigner::TabWidget>(
 							widgetToFocus, "KFormDesigner::TabWidget", pageFor_widgetToFocus);
-					if (tabWidgetFor_widgetToFocus && TQT_BASE_OBJECT(tabWidgetFor_widgetToFocus->currentPage())!=TQT_BASE_OBJECT(pageFor_widgetToFocus)) {
+					if (tabWidgetFor_widgetToFocus && tabWidgetFor_widgetToFocus->currentPage()!=pageFor_widgetToFocus) {
 						realWidget = widgetToFocus;
 						continue; //the new widget to focus is placed on invisible tab page: move to next widget
 					}
@@ -691,24 +691,4 @@ void KexiDBForm::setCursor( const TQCursor & cursor )
 		KexiDBFormBase::setCursor(cursor);
 }
 
-//! @todo: TQt4? XORed resize rectangles instead of black widgets
-/*
-void KexiDBForm::paintEvent( TQPaintEvent *e )
-{
-	TQPainter p;
-	p.begin(this, true);
-	bool unclipped = testWFlags( WPaintUnclipped );
-	setWFlags( WPaintUnclipped );
-
-	p.setPen(white);
-	p.setRasterOp(XorROP);
-	p.drawLine(e->rect().topLeft(), e->rect().bottomRight());
-
-	if (!unclipped)
-		clearWFlags( WPaintUnclipped );
-	p.end();
-	KexiDBFormBase::paintEvent(e);
-}
-*/
-
 #include "kexidbform.moc"
