@@ -91,7 +91,7 @@ KexiDBImageBox::KexiDBImageBox( bool designMode, TQWidget *parent, const char *n
 	}
 	else {
 		m_chooser = new KexiDropDownButton(this);
-		m_chooser->setFocusPolicy(TQ_StrongFocus);
+		m_chooser->setFocusPolicy(TQWidget::StrongFocus);
 		m_chooser->setPopup(m_popupMenu);
 		setFocusProxy(m_chooser);
 		m_chooser->installEventFilter(this);
@@ -711,7 +711,7 @@ void KexiDBImageBox::updatePixmap()
 		KexiDBImageBox_pmDeleter.setObject( KexiDBImageBox_pm, new TQPixmap(fname, "PNG") );
 		TQImage img(KexiDBImageBox_pm->convertToImage());
 		KexiDBImageBox_pmSmallDeleter.setObject( KexiDBImageBox_pmSmall, 
-			new TQPixmap( img.smoothScale(img.width()/2, img.height()/2, TQ_ScaleMin) ) );
+			new TQPixmap( img.smoothScale(img.width()/2, img.height()/2, TQImage::ScaleMin) ) );
 	}
 }
 
@@ -837,31 +837,31 @@ bool KexiDBImageBox::subwidgetStretchRequired(KexiDBAutoField* autoField) const
 
 bool KexiDBImageBox::eventFilter( TQObject * watched, TQEvent * e )
 {
-	if (TQT_BASE_OBJECT(watched)==TQT_BASE_OBJECT(this) || TQT_BASE_OBJECT(watched)==TQT_BASE_OBJECT(m_chooser)) { //we're watching chooser as well because it's a focus proxy even if invisible
+	if (watched==this || watched==m_chooser) { //we're watching chooser as well because it's a focus proxy even if invisible
 		if (e->type()==TQEvent::FocusIn || e->type()==TQEvent::FocusOut || e->type()==TQEvent::MouseButtonPress) {
 			update(); //to repaint focus rect
 		}
 	}
 	// hide popup menu as soon as it loses focus
-	if (TQT_BASE_OBJECT(watched)==TQT_BASE_OBJECT(m_popupMenu) && e->type()==TQEvent::FocusOut) {
+	if (watched==m_popupMenu && e->type()==TQEvent::FocusOut) {
 		m_popupMenu->hide();
 	}
 	return KexiFrame::eventFilter(watched, e);
 }
 
-TQ_FocusPolicy KexiDBImageBox::focusPolicy() const
+TQWidget::FocusPolicy KexiDBImageBox::focusPolicy() const
 {
 	if (dataSource().isEmpty())
-		return TQ_NoFocus;
+		return TQWidget::NoFocus;
 	return m_focusPolicyInternal;
 }
 
-TQ_FocusPolicy KexiDBImageBox::focusPolicyInternal() const
+TQWidget::FocusPolicy KexiDBImageBox::focusPolicyInternal() const
 {
 	return m_focusPolicyInternal;
 }
 
-void KexiDBImageBox::setFocusPolicy( TQ_FocusPolicy policy )
+void KexiDBImageBox::setFocusPolicy( TQWidget::FocusPolicy policy )
 {
 	m_focusPolicyInternal = policy;
 	KexiFrame::setFocusPolicy( focusPolicy() ); //set modified policy
