@@ -80,8 +80,8 @@ void KexiDBLineEdit::setInvalidState( const TQString& displayText )
 {
 	KLineEdit::setReadOnly(true);
 //! @todo move this to KexiDataItemInterface::setInvalidStateInternal() ?
-	if (focusPolicy() & TQ_TabFocus)
-		setFocusPolicy(TQ_ClickFocus);
+	if (focusPolicy() & TQWidget::TabFocus)
+		setFocusPolicy(TQWidget::ClickFocus);
 	setText(displayText);
 }
 
