@@ -47,8 +47,8 @@ void KexiDBTextEdit::setInvalidState( const TQString& displayText )
 {
 	setReadOnly(true);
 //! @todo move this to KexiDataItemInterface::setInvalidStateInternal() ?
-	if (focusPolicy() & TQ_TabFocus)
-		setFocusPolicy(TQ_ClickFocus);
+	if (focusPolicy() & TQWidget::TabFocus)
+		setFocusPolicy(TQWidget::ClickFocus);
 	KTextEdit::setText(displayText);
 }
 
