@@ -56,7 +56,7 @@ void KexiDBTimeEdit::setInvalidState( const TQString&)
 	m_invalidState = true;
 //! @todo move this to KexiDataItemInterface::setInvalidStateInternal() ?
 	if (focusPolicy() & TabFocus)
-		setFocusPolicy(TQ_ClickFocus);
+		setFocusPolicy(TQWidget::ClickFocus);
 }
 
 void
