@@ -708,7 +708,6 @@ tristate KexiCSVImportDialog::loadRows(TQString &field, int &row, int &column, i
 		if (offset==0 && x.unicode()==0xfeff) {
 			// Ignore BOM, the "Byte Order Mark" 
 			// (http://en.wikipedia.org/wiki/Byte_Order_Mark, // http://www.unicode.org/charts/PDF/UFFF0.pdf)
-			// Probably fixed in TQt4.
 			continue;
 		}
 
@@ -1630,7 +1629,7 @@ bool KexiCSVImportDialog::eventFilter ( TQObject * watched, TQEvent * e )
 		|| t==TQEvent::Paint ))
 		return true;
 
-	if (TQT_BASE_OBJECT(watched) == TQT_BASE_OBJECT(m_startAtLineSpinBox) && t==TQEvent::KeyPress) {
+	if (watched == m_startAtLineSpinBox && t==TQEvent::KeyPress) {
 		TQKeyEvent *ke = TQT_TQKEYEVENT(e);
 		if (ke->key()==TQt::Key_Enter || ke->key()==TQt::Key_Return) {
 			m_table->setFocus();
