@@ -132,7 +132,7 @@ KexiPropertyEditorView::KexiPropertyEditorView(KexiMainWindow *mainWin, TQWidget
 	lyr->addWidget(d->editor);
 	setFocusProxy(d->editor);
 	d->objectInfoLabel->setBuddy(d->editor);
-	setFocusPolicy(TQ_WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus);
 
 	connect(d->editor, TQT_SIGNAL(propertySetChanged(KoProperty::Set*)), 
 		this, TQT_SLOT(slotPropertySetChanged(KoProperty::Set*)));
