@@ -60,7 +60,7 @@ KexiScrollView::KexiScrollView(TQWidget *parent, bool preview)
 //		(fc.blue()+bc.blue()*2)/3);
 	m_helpFont.setPointSize( m_helpFont.pointSize() * 3 );
 
-	setFocusPolicy(TQ_WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus);
 
 	//initial resize mode is always manual;
 	//will be changed on show(), if needed
@@ -253,7 +253,7 @@ KexiScrollView::contentsMouseMoveEvent(TQMouseEvent *ev)
 			tmpy = contentsY();
 
 		// we look for the max widget right() (or bottom()), which would be the limit for form resizing (not to hide widgets)
-		TQObjectList *list = m_widget->queryList(TQWIDGET_OBJECT_NAME_STRING, 0, true, false /* not recursive*/);
+		TQObjectList *list = m_widget->queryList("TQWidget", 0, true, false /* not recursive*/);
 		for(TQObject *o = list->first(); o; o = list->next())
 		{
 			TQWidget *w = (TQWidget*)o;
