@@ -26,7 +26,7 @@ class KexiSectionHeaderPrivate;
 
 class KEXIEXTWIDGETS_EXPORT KexiSectionHeader : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		class BoxLayout;
