@@ -343,7 +343,7 @@ PixmapCollectionEditor::getPixmap(const TQString &name)
 
 	KPixmapIO io;
 	TQImage image = io.convertToImage(pixmap);
-	pixmap = io.convertToPixmap(image.scale(48, 48, TQ_ScaleMin));
+	pixmap = io.convertToPixmap(image.scale(48, 48, TQImage::ScaleMin));
 	return pixmap;
 }
 
@@ -420,7 +420,7 @@ PixmapCollectionChooser::getPixmap(const TQString &name)
 	// We scale the pixmap down to 48x48 to fit in the iconView
 	KPixmapIO io;
 	TQImage image = io.convertToImage(pixmap);
-	pixmap = io.convertToPixmap(image.scale(48, 48, TQ_ScaleMin));
+	pixmap = io.convertToPixmap(image.scale(48, 48, TQImage::ScaleMin));
 	return pixmap;
 }
 
