@@ -58,7 +58,7 @@ KexiRelationView::KexiRelationView(TQWidget *parent, const char *name)
 //	connect(relation, TQT_SIGNAL(relationListUpdated(TQObject *)), this, TQT_SLOT(slotListUpdate(TQObject *)));
 
 	viewport()->setPaletteBackgroundColor(colorGroup().mid());
-	setFocusPolicy(TQ_WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus);
 	setResizePolicy(Manual);
 /*MOVED TO KexiRelationDialog
 	//actions
