@@ -221,13 +221,13 @@ KexiRelationWidget::addTable(const TQString& t)
 
 void KexiRelationWidget::tableViewGotFocus()
 {
-//	if (m_relationView->focusedTableView == TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())))
+//	if (m_relationView->focusedTableView == sender())
 //		return;
 //	kdDebug() << "GOT FOCUS!" <<endl;
 //	clearSelection();
 //	if (m_focusedTableView)
 //		m_focusedTableView->unsetFocus();
-//	m_focusedTableView = (KexiRelationViewTableContainer*)TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
+//	m_focusedTableView = (KexiRelationViewTableContainer*)sender();
 	invalidateActions();
 }
 
@@ -339,9 +339,9 @@ void KexiRelationWidget::aboutToShowPopupMenu()
 void
 KexiRelationWidget::slotTableFieldDoubleClicked(TQListViewItem *i,const TQPoint&,int)
 {
-	if (!TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->isA("KexiRelationViewTable"))
+	if (!sender()->isA("KexiRelationViewTable"))
 		return;
-	const KexiRelationViewTable* t = static_cast<const KexiRelationViewTable*>(TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
+	const KexiRelationViewTable* t = static_cast<const KexiRelationViewTable*>(sender());
 	const TQStringList selectedFieldNames( t->selectedFieldNames() );
 	if (selectedFieldNames.count()==1)
 		emit tableFieldDoubleClicked( t->schema()->table(), selectedFieldNames.first() );
