@@ -120,7 +120,7 @@ KexiTableEdit::eventFilter(TQObject* watched, TQEvent* e)
 		}
 	}*/
 
-	if(TQT_BASE_OBJECT(watched) == TQT_BASE_OBJECT(this))
+	if(watched == this)
 	{
 		if(e->type() == TQEvent::KeyPress)
 		{
