@@ -192,9 +192,9 @@ KexiTableView::KexiTableView(KexiTableViewData* data, TQWidget* parent, const ch
 
 	setResizePolicy(Manual);
 	viewport()->setBackgroundMode(TQt::NoBackground);
-//	viewport()->setFocusPolicy(TQ_StrongFocus);
-	viewport()->setFocusPolicy(TQ_WheelFocus);
-	setFocusPolicy(TQ_WheelFocus); //<--- !!!!! important (was NoFocus), 
+//	viewport()->setFocusPolicy(TQWidget::StrongFocus);
+	viewport()->setFocusPolicy(TQWidget::WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus); //<--- !!!!! important (was NoFocus), 
 	//                             otherwise TQApplication::setActiveWindow() won't activate 
 	//                             this widget when needed!
 //	setFocusProxy(viewport());
@@ -1264,7 +1264,7 @@ void KexiTableView::keyPressEvent(TQKeyEvent* e)
 	TQWidget *w = focusWidget();
 //	if (!w || w!=viewport() && w!=this && (!m_editor || w!=m_editor->view() && w!=m_editor)) {
 //	if (!w || w!=viewport() && w!=this && (!m_editor || w!=m_editor->view())) {
-	if (!w || TQT_BASE_OBJECT(w)!=TQT_BASE_OBJECT(viewport()) && TQT_TQOBJECT(w)!=TQT_TQOBJECT(this) && (!m_editor || !KexiUtils::hasParent(TQT_TQOBJECT(dynamic_cast<TQT_BASE_OBJECT_NAME*>(m_editor)), TQT_TQOBJECT(w)))) {
+	if (!w || w!=viewport() && TQT_TQOBJECT(w)!=TQT_TQOBJECT(this) && (!m_editor || !KexiUtils::hasParent(TQT_TQOBJECT(dynamic_cast<TQObject*>(m_editor)), TQT_TQOBJECT(w)))) {
 		//don't process stranger's events
 		e->ignore();
 		return;
@@ -2422,7 +2422,7 @@ bool KexiTableView::eventFilter( TQObject *o, TQEvent *e )
 				ke->accept();
 				return true;
 			}
-			else if (m_editor && (o==dynamic_cast<TQT_BASE_OBJECT_NAME*>(m_editor) || TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(m_editor->widget()))) {
+			else if (m_editor && (o==dynamic_cast<TQObject*>(m_editor) || o==m_editor->widget())) {
 				if ( (k==TQt::Key_Tab && (s==Qt::NoButton || s==TQt::ShiftButton))
 					|| (overrideEditorShortcutNeeded(ke))
 					|| (k==TQt::Key_Enter || k==TQt::Key_Return || k==TQt::Key_Up || k==TQt::Key_Down) 
@@ -2450,14 +2450,14 @@ bool KexiTableView::eventFilter( TQObject *o, TQEvent *e )
 			}*/
 		}
 	}
-	else if (TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(horizontalScrollBar())) {
+	else if (o==horizontalScrollBar()) {
 		if ((e->type()==TQEvent::Show && !horizontalScrollBar()->isVisible()) 
 			|| (e->type()==TQEvent::Hide && horizontalScrollBar()->isVisible())) {
 			updateWidgetContentsSize();
 		}
 	}
 	else if (e->type()==TQEvent::Leave) {
-		if (TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(viewport()) && d->appearance.rowMouseOverHighlightingEnabled
+		if (o==viewport() && d->appearance.rowMouseOverHighlightingEnabled
 			&& d->appearance.persistentSelections)
 		{
 			if (d->highlightedRow!=-1) {
@@ -2476,7 +2476,7 @@ bool KexiTableView::eventFilter( TQObject *o, TQEvent *e )
 		}
 		d->recentCellWithToolTip = TQPoint(-1,-1);
 	}
-/*	else if (e->type()==TQEvent::FocusOut && o->inherits(TQWIDGET_OBJECT_NAME_STRING)) {
+/*	else if (e->type()==TQEvent::FocusOut && o->inherits("TQWidget")) {
 		//hp==true if currently focused widget is a child of this table view
 		const bool hp = KexiUtils::hasParent( static_cast<TQWidget*>(o), focusWidget());
 		if (!hp && KexiUtils::hasParent( this, static_cast<TQWidget*>(o))) {
