@@ -38,7 +38,7 @@ class KexiTableViewHeaderStyle : public KexiUtils::StyleProxy
 		}
 		~KexiTableViewHeaderStyle() {}
 
-		virtual void drawPrimitive( TQ_PrimitiveElement pe,
+		virtual void drawPrimitive( PrimitiveElement pe,
 			TQPainter *p, const TQRect &r, const TQColorGroup &cg, SFlags flags = Style_Default,
 			const TQStyleOption& option = TQStyleOption::Default ) const
 		{
