@@ -59,10 +59,6 @@ class KEXIGUIUTILS_EXPORT KexiFlowLayout : public TQLayout
 
 		virtual bool isEmpty();
 
-#ifdef USE_QT4
-		QLAYOUT_REQUIRED_METHOD_DECLARATIONS
-#endif // USE_QT4
-
 	protected:
 		virtual void setGeometry(const TQRect&);
 		int simulateLayout(const TQRect &r);
