@@ -26,7 +26,7 @@ namespace Kivio {
 
 class DragBarButton : public TQPushButton
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     DragBarButton( const TQString&, TQWidget* parent, const char* name = 0 );
