@@ -44,7 +44,7 @@ class KivioView;
 
 class StencilBarDockManager : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     enum BarPos {
@@ -93,7 +93,7 @@ class StencilBarDockManager : public TQWidget
  */
 class KoToolDockMoveManager: public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
