@@ -26,7 +26,7 @@ namespace Kivio {
 
 class KIVIO_EXPORT MouseToolAction : public TDERadioAction
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     /**
