@@ -216,7 +216,7 @@ Navigator::Navigator(bool _selectable, TDEPopupMenu * menu, IconSidePane *_icons
   executedItem = 0;
   mMouseOn = 0;
 
-  setFocusPolicy( TQ_NoFocus );
+  setFocusPolicy( TQWidget::NoFocus );
 
   connect( this, TQT_SIGNAL( clicked( TQListBoxItem* ) ),
            TQT_SLOT( slotExecuted( TQListBoxItem* ) ) );
@@ -495,7 +495,7 @@ int IconSidePane::insertGroup(const TQString &_text, bool _selectable, TQObject
   m_buttongroup->insert( b, id );
   connect( b, TQT_SIGNAL( clicked() ), this, TQT_SLOT( buttonClicked() ) );
   b->setToggleButton( true );
-  b->setFocusPolicy( TQ_NoFocus );
+  b->setFocusPolicy( TQWidget::NoFocus );
   if (m_buttongroup->count()==1)
   {
     mCurrentNavigator->calculateMinWidth();
