@@ -45,7 +45,7 @@ class Calendar;
  **/
 class CalendarPanel: public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     TQ_PROPERTY( TQDate date READ date WRITE setDate)
     TQ_PROPERTY( bool closeButton READ hasCloseButton WRITE setCloseButton )
