@@ -90,7 +90,7 @@ DateTable::DateTable(TQWidget *parent, TQDate date_, const char* name, WFlags f)
         kdError() <<k_funcinfo<<"Given date is invalid, using current date." << endl;
         date_=TQDate::currentDate();
     }
-    setFocusPolicy( TQ_StrongFocus );
+    setFocusPolicy( TQWidget::StrongFocus );
     setNumCols(7+m_dateStartCol); // 7 days a week + maybe 1 for weeknumbers
     setNumRows(7); // 6 weeks max + headline
 
