@@ -45,7 +45,7 @@ class Context;
 class GanttView;
 
 class Part : public KoDocument, public KoTextZoomHandler {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
