@@ -940,10 +940,10 @@ void KoPenCmd::execute()
     {
         Pen tmpPen = *oldPen.at( i );
 
-        if ( flags & LineBegin )
+        if ( flags & BeginLine )
             tmpPen.lineBegin = newPen.lineBegin;
 
-        if ( flags & LineEnd )
+        if ( flags & EndLine )
             tmpPen.lineEnd = newPen.lineEnd;
 
         if ( flags & Color )
