@@ -545,7 +545,7 @@ TQPixmap KPrThumbBar::getSlideThumb(int slideNr) const
         h = 130;
     }
 
-    const TQImage img(pix.convertToImage().smoothScale( w, h, TQ_ScaleMin ));
+    const TQImage img(pix.convertToImage().smoothScale( w, h, TQImage::ScaleMin ));
     pix.convertFromImage(img);
 
     // draw a frame around the thumb to show its size
