@@ -117,7 +117,7 @@ private:
 class KPrView : public KoView
 {
     friend class PageBase;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
