@@ -48,7 +48,7 @@ class View;
  */
 class FormatDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
   FormatDialog( View* view, const char* name = 0 );
