@@ -271,15 +271,15 @@ void FormulaDialog::slotSearchText(const TQString &_text)
 
 bool FormulaDialog::eventFilter( TQObject* obj, TQEvent* ev )
 {
-    if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(firstElement) && ev->type() == TQEvent::FocusIn )
+    if ( obj == firstElement && ev->type() == TQEvent::FocusIn )
         m_focus = firstElement;
-    else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(secondElement) && ev->type() == TQEvent::FocusIn )
+    else if ( obj == secondElement && ev->type() == TQEvent::FocusIn )
         m_focus = secondElement;
-    else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(thirdElement) && ev->type() == TQEvent::FocusIn )
+    else if ( obj == thirdElement && ev->type() == TQEvent::FocusIn )
         m_focus = thirdElement;
-    else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(fourElement) && ev->type() == TQEvent::FocusIn )
+    else if ( obj == fourElement && ev->type() == TQEvent::FocusIn )
         m_focus = fourElement;
-    else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(fiveElement) && ev->type() == TQEvent::FocusIn )
+    else if ( obj == fiveElement && ev->type() == TQEvent::FocusIn )
         m_focus = fiveElement;
     else
         return FALSE;
