@@ -49,7 +49,7 @@ class View;
 
 class FormulaDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
   FormulaDialog( View* parent, const char* name,const TQString& formulaName=0);
