@@ -47,7 +47,7 @@ class View;
 
 class GoalSeekDialog : public KDialog
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
