@@ -88,7 +88,7 @@ KudesignerView::KudesignerView( KudesignerDoc* part, TQWidget* parent, const cha
     l->addWidget( m_view );
 
     m_view->viewport() ->setFocusProxy( m_view );
-    m_view->viewport() ->setFocusPolicy( TQ_WheelFocus );
+    m_view->viewport() ->setFocusPolicy( TQWidget::WheelFocus );
     m_view->setFocus();
 
     m_view->itemToInsert = 0;
