@@ -40,7 +40,7 @@ namespace Kugar
 
 class KUGAR_EXPORT MReportViewer : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
