@@ -115,7 +115,7 @@ KWCanvas::KWCanvas(const TQString& viewMode, TQWidget *parent, KWDocument *d, KW
              this, TQT_SLOT( doAutoScroll() ) );
 
     viewport()->setFocusProxy( this );
-    viewport()->setFocusPolicy( TQ_WheelFocus );
+    viewport()->setFocusPolicy( TQWidget::WheelFocus );
     setInputMethodEnabled( true );
     setFocus();
     viewport()->installEventFilter( this );
@@ -1699,9 +1699,9 @@ void KWCanvas::updateRulerOffsets( int cx, int cy )
 
 bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
 {
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(viewport()) ) {
+    if ( o == this || o == viewport() ) {
 
-        if(m_currentFrameSetEdit && TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) )
+        if(m_currentFrameSetEdit && o == this )
         {
             // Pass event to auto-hide-cursor code (see kcursor.h for details)
             KCursor::autoHideEventFilter( o, e );
