@@ -59,7 +59,7 @@ class KWFrameView;
  */
 class KWCanvas : public TQScrollView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
