@@ -173,7 +173,7 @@ public:
         TDEGlobal::iconLoader()->addAppDir("koffice");
         m_view = 0L;
         // Avoid warning from KParts - we'll have the KoView as focus proxy anyway
-        setFocusPolicy( TQ_ClickFocus );
+        setFocusPolicy( TQWidget::ClickFocus );
     }
 
     virtual ~KoViewWrapperWidget() {
@@ -182,7 +182,7 @@ public:
 
     virtual void resizeEvent( TQResizeEvent * )
     {
-        TQObject *wid = child( 0, TQWIDGET_OBJECT_NAME_STRING );
+        TQObject *wid = child( 0, "TQWidget" );
         if ( wid )
             TQT_TQWIDGET(wid)->setGeometry( 0, 0, width(), height() );
     }
