@@ -1315,7 +1315,7 @@ void KoMainWindow::slotToolbarToggled( bool toggle )
 {
   //kdDebug(30003) << "KoMainWindow::slotToolbarToggled " << sender()->name() << " toggle=" << true << endl;
   // The action (sender) and the toolbar have the same name
-  TDEToolBar * bar = toolBar( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() );
+  TDEToolBar * bar = toolBar( sender()->name() );
   if (bar)
   {
     if (toggle)
@@ -1327,7 +1327,7 @@ void KoMainWindow::slotToolbarToggled( bool toggle )
         saveMainWindowSettings( TDEGlobal::config(), rootDocument()->instance()->instanceName() );
   }
   else
-    kdWarning(30003) << "slotToolbarToggled : Toolbar " << TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() << " not found!" << endl;
+    kdWarning(30003) << "slotToolbarToggled : Toolbar " << sender()->name() << " not found!" << endl;
 }
 
 bool KoMainWindow::toolbarIsVisible(const char *tbName)
