@@ -126,7 +126,7 @@ bool KoOasisStore::closeManifestWriter()
 {
     m_manifestWriter->endElement();
     m_manifestWriter->endDocument();
-    TQBuffer* buffer = TQT_TQBUFFER( static_cast<QIODevice*>(m_manifestWriter->device()) );
+    TQBuffer* buffer = TQT_TQBUFFER( static_cast<TQIODevice*>(m_manifestWriter->device()) );
     delete m_manifestWriter; m_manifestWriter = 0;
     bool ok = false;
     if ( m_store->open( "META-INF/manifest.xml" ) )
