@@ -275,7 +275,7 @@ TQListViewItem* KoOpenPane::addPane(const TQString& title, const TQPixmap& icon,
     TQImage image = icon.convertToImage();
 
     if((image.width() > 48) || (image.height() > 48)) {
-      image = image.smoothScale(48, 48, TQ_ScaleMin);
+      image = image.smoothScale(48, 48, TQImage::ScaleMin);
     }
 
     image.setAlphaBuffer(true);
