@@ -116,7 +116,7 @@ KoView::KoView( KoDocument *document, TQWidget *parent, const char *name )
   d->m_doc = document;
   KParts::PartBase::setPartObject( TQT_TQOBJECT(this) );
 
-  setFocusPolicy( TQ_StrongFocus );
+  setFocusPolicy( TQWidget::StrongFocus );
 
   setMouseTracking( true );
 
