@@ -265,7 +265,7 @@ bool KKbdAccessExtensions::eventFilter( TQObject *o, TQEvent *e )
         showIcon();
         return true;
     }
-    else if (e->type() == TQEvent::Resize && d->panel && TQT_BASE_OBJECT(o) == d->panel) {
+    else if (e->type() == TQEvent::Resize && d->panel && o == d->panel) {
         // TODO: This doesn't always work.
         showIcon();
     }
