@@ -148,7 +148,7 @@ KoPageLayoutDia::KoPageLayoutDia( TQWidget* parent, const char* name,
     if ( tabs & FORMAT_AND_BORDERS ) setupTab1( true );
     if ( tabs & HEADER_AND_FOOTER ) setupTab2( hf );
 
-    setFocusPolicy( TQ_StrongFocus );
+    setFocusPolicy( TQWidget::StrongFocus );
     setFocus();
 }
 
@@ -176,7 +176,7 @@ KoPageLayoutDia::KoPageLayoutDia( TQWidget* parent, const char* name,
     if ( tabs & COLUMNS ) setupTab3();
     if ( tabs & KW_HEADER_AND_FOOTER ) setupTab4(kwhf);
 
-    setFocusPolicy( TQ_StrongFocus );
+    setFocusPolicy( TQWidget::StrongFocus );
     setFocus();
 }
 
