@@ -64,7 +64,7 @@ void KoPartSelectAction::init()
 // Called when selecting a part
 void KoPartSelectAction::slotActionActivated()
 {
-    TQString servName = TQString::fromLatin1( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() );
+    TQString servName = TQString::fromLatin1( sender()->name() );
     KService::Ptr serv = KService::serviceByName( servName );
     m_documentEntry = KoDocumentEntry( serv );
     emit activated();
