@@ -100,7 +100,7 @@ class KoRulerPrivate;
  */
 class KOFFICEUI_EXPORT KoRuler : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     friend class KoRulerPrivate; // for the Action enum
 public:
