@@ -90,7 +90,7 @@ int KoSelectAction::plug(TQWidget* widget, int index)
   if (kapp && !kapp->authorizeTDEAction(name()))
     return -1;
   kdDebug(129) << "TDEAction::plug( " << widget << ", " << index << " )" << endl; // remove -- ellis
-  if ( widget->inherits(TQPOPUPMENU_OBJECT_NAME_STRING) )
+  if ( widget->inherits("TQPopupMenu") )
   {
     TQPopupMenu* menu = static_cast<TQPopupMenu*>( widget );
     int id;
@@ -144,7 +144,7 @@ int KoSelectAction::plug(TQWidget* widget, int index)
 
     return containerCount() - 1;
   }
-  else if ( widget->inherits( TQMENUBAR_OBJECT_NAME_STRING ) )
+  else if ( widget->inherits( "TQMenuBar" ) )
   {
     TQMenuBar *bar = static_cast<TQMenuBar *>( widget );
 
