@@ -30,7 +30,7 @@ class TQPoint;
  */
 class KOFFICEUI_EXPORT KoSelectAction : public TDEAction
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     /** Constructs a KoSelectAction with a text and an icon.
