@@ -357,7 +357,7 @@ void KoTemplateChooseDia::setupFileDialog(TQWidget * widgetbase, TQGridLayout *
     d->m_filedialog->reparent( widgetbase , point );
     //d->m_filedialog->setOperationMode( KFileDialog::Opening);
 
-    TQObjectList *l = d->m_filedialog->queryList( TQPUSHBUTTON_OBJECT_NAME_STRING );
+    TQObjectList *l = d->m_filedialog->queryList( "TQPushButton" );
     TQObjectListIt childit( *l );
     TQObject *obj;
     while ( (obj = childit.current()) != 0 ) {
