@@ -42,7 +42,7 @@ class TQGridLayout;
  */
 class KoTCDIconCanvas : public TDEIconCanvas
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
 	KoTCDIconCanvas( TQWidget *parent = 0, const char *name = 0L )
@@ -93,7 +93,7 @@ class KoTCDIconViewItem : public TDEIconViewItem
  * @internal
  */
 class KoTCDRecentFilesIconView : public KFileIconView {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
 	KoTCDRecentFilesIconView( TQWidget* parent, const char* name ) :
@@ -132,7 +132,7 @@ class KoTemplateChooseDiaPrivate;
  */
 class KOFFICEUI_EXPORT KoTemplateChooseDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
