@@ -309,7 +309,7 @@ void KoColorPanel::mousePressEvent( TQMouseEvent* e )
 
 void KoColorPanel::mouseReleaseEvent( TQMouseEvent* )
 {
-    if ( isVisible() && parentWidget() && parentWidget()->inherits( TQPOPUPMENU_OBJECT_NAME_STRING ) )
+    if ( isVisible() && parentWidget() && parentWidget()->inherits( "TQPopupMenu" ) )
         parentWidget()->close();
     emit colorSelected( mapToColor( m_pressedPos ) );
 }
@@ -425,7 +425,7 @@ void KoColorPanel::keyPressEvent( TQKeyEvent* e )
             e->ignore();
     }
     else if ( e->key() == TQt::Key_Return ) {
-        if ( isVisible() && parentWidget() && parentWidget()->inherits( TQPOPUPMENU_OBJECT_NAME_STRING ) )
+        if ( isVisible() && parentWidget() && parentWidget()->inherits( "TQPopupMenu" ) )
             parentWidget()->close();
         emit colorSelected( mapToColor( m_focusPosition ) );
     }
@@ -458,7 +458,7 @@ void KoColorPanel::finalizeInsertion( const Position& pos )
     paint( pos );
 
     if ( !isFocusEnabled() )
-        setFocusPolicy( TQ_StrongFocus );
+        setFocusPolicy( TQWidget::StrongFocus );
     // Did we start a new row?
     if ( m_nextPosition.x == 1 )
         updateGeometry();
@@ -599,7 +599,7 @@ void KoColorPanel::paint( const Position& position )
 
 void KoColorPanel::init()
 {
-    setFocusPolicy( TQ_NoFocus ); // it's empty
+    setFocusPolicy( TQWidget::NoFocus ); // it's empty
     m_nextPosition.x = 0;
     m_nextPosition.y = 0;
     m_focusPosition.x = -1;
@@ -809,7 +809,7 @@ void KoToolButton::drawButton(TQPainter *_painter)
 
 bool KoToolButton::eventFilter( TQObject* o, TQEvent* e )
 {
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_popup) ) {
+    if ( o == m_popup ) {
         if ( e->type() == TQEvent::MouseButtonPress )
             if ( hitArrow( mapFromGlobal( TQT_TQMOUSEEVENT( e )->globalPos() ) ) ) {
                 kdDebug() << "KoToolButton::eventFilter-------------->" << endl;
