@@ -25,7 +25,7 @@
 /** A line style selection action */
 class KOFFICEUI_EXPORT KoLineStyleAction : public KoSelectAction
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     /** Constructs a KoLineStyleAction with a text and an icon.
