@@ -29,7 +29,7 @@
 /** A line width selection action */
 class KOFFICEUI_EXPORT KoLineWidthAction : public KoSelectAction
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     /** Constructs a KoLineWidthAction with a text and an icon.
@@ -87,7 +87,7 @@ class KOFFICEUI_EXPORT KoLineWidthAction : public KoSelectAction
 /** This class provides a dialog for setting a custom line width. */
 class KoLineWidthChooser : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     KoLineWidthChooser(TQWidget* parent = 0, const char* name = 0);
