@@ -237,7 +237,7 @@ int TDESelectColorAction::plug( TQWidget* w, int index )
     if (kapp && !kapp->authorizeTDEAction(name()))
         return -1;
 
-    if ( w->inherits(TQPOPUPMENU_OBJECT_NAME_STRING) )
+    if ( w->inherits("TQPopupMenu") )
     {
         TQPopupMenu* menu = static_cast<TQPopupMenu*>( w );
         int id;
