@@ -497,7 +497,7 @@ void KoPaletteManager::showAllPalettes(bool shown)
 
 bool KoPaletteManager::eventFilter( TQObject *o, TQEvent *e )
 {
-    if (TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(m_view)) return false;
+    if (o != m_view) return false;
 
     if(e && e->type() == (TQEvent::User + 42)) {
          KParts::PartActivateEvent * pae = dynamic_cast<KParts::PartActivateEvent *>(e);
