@@ -52,7 +52,7 @@ class FontEditRequester : public TDEFontRequester
 			label()->setFrameShape(TQFrame::Box);
 			label()->setIndent(-1);
 #if TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
-			label()->setFocusPolicy(TQ_ClickFocus);
+			label()->setFocusPolicy(TQWidget::ClickFocus);
 			TDEAcceleratorManager::setNoAccel(label());
 #endif
 			layout()->remove(label());
@@ -60,7 +60,7 @@ class FontEditRequester : public TDEFontRequester
 			delete layout();
 			button()->setText(i18n("..."));
 			TQToolTip::add(button(), i18n("Change font"));
-			button()->setFocusPolicy(TQ_NoFocus);
+			button()->setFocusPolicy(TQWidget::NoFocus);
 			button()->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
 			TQFontMetrics fm(button()->font());
 			button()->setFixedWidth(fm.width(button()->text()+' '));
