@@ -70,7 +70,7 @@ PixmapEdit::PixmapEdit(Property *property, TQWidget *parent, const char *name)
 	m_button->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
 	TQFontMetrics fm(m_button->font());
 	m_button->setFixedWidth(fm.width(m_button->text()+' '));
-	m_button->setFocusPolicy(TQ_NoFocus);
+	m_button->setFocusPolicy(TQWidget::NoFocus);
 
 	m_popup = new TQLabel(0, "m_popup", TQt::WStyle_Customize|TQt::WStyle_NoBorder|TQt::WX11BypassWM|WStyle_StaysOnTop);
 	m_popup->setPaletteBackgroundColor(m_popup->palette().active().base());
@@ -105,13 +105,13 @@ PixmapEdit::setValue(const TQVariant &value, bool emitChange)
 	else {
 		TQImage img(m_pixmap.convertToImage());
 		if (!TQRect(TQPoint(0,0), m_edit->size()*3).contains(m_pixmap.rect())) {
-			img = img.smoothScale(m_edit->size()*3, TQ_ScaleMin);
+			img = img.smoothScale(m_edit->size()*3, TQImage::ScaleMin);
 			m_previewPixmap.convertFromImage(img);//preview pixmap is a bit larger
 		}
 		else {
 			m_previewPixmap = m_pixmap;
 		}
-		img = img.smoothScale(m_edit->size(), TQ_ScaleMin);
+		img = img.smoothScale(m_edit->size(), TQImage::ScaleMin);
 		TQPixmap pm;
 		pm.convertFromImage(img);
 		m_edit->setPixmap(pm);
@@ -135,7 +135,7 @@ PixmapEdit::drawViewer(TQPainter *p, const TQColorGroup &, const TQRect &r, cons
 		m_scaledPixmap = value.toPixmap();
 		if (m_scaledPixmap.height() > r2.height() || m_scaledPixmap.width() > r2.width()) { //scale down
 			TQImage img(m_scaledPixmap.convertToImage());
-			img = img.smoothScale(r2.size()/*+TQSize(0,2)*/, TQ_ScaleMin);
+			img = img.smoothScale(r2.size()/*+TQSize(0,2)*/, TQImage::ScaleMin);
 			m_scaledPixmap.convertFromImage(img);
 		}
 	}
@@ -205,7 +205,7 @@ PixmapEdit::resizeEvent(TQResizeEvent *e)
 bool
 PixmapEdit::eventFilter(TQObject *o, TQEvent *ev)
 {
-	if(TQT_BASE_OBJECT(o) == m_edit) {
+	if(o == m_edit) {
 		if(ev->type() == TQEvent::MouseButtonPress && TQT_TQMOUSEEVENT(ev)->button()==Qt::LeftButton) {
 			if(m_previewPixmap.height() <= m_edit->height()
 				&& m_previewPixmap.width() <= m_edit->width())
