@@ -39,7 +39,7 @@ IntSpinBox::IntSpinBox(int lower, int upper, int step, int value, int base, IntE
 	editor()->setAlignment(TQt::AlignLeft);
 	installEventFilter(editor());
 	installEventFilter(this);
-	TQObjectList *spinwidgets = queryList( TQSPINWIDGET_OBJECT_NAME_STRING, 0, false, true );
+	TQObjectList *spinwidgets = queryList( "TQSpinWidget", 0, false, true );
 	TQSpinWidget* spin = static_cast<TQSpinWidget*>(TQT_TQWIDGET(spinwidgets->first()));
 	if (spin)
 		spin->installEventFilter(this);
@@ -59,7 +59,7 @@ void IntSpinBox::setValue(const TQVariant &value)
 bool
 IntSpinBox::eventFilter(TQObject *o, TQEvent *e)
 {
-	if(TQT_BASE_OBJECT(o) == editor())
+	if(o == editor())
 	{
 		if(e->type() == TQEvent::KeyPress)
 		{
@@ -71,7 +71,7 @@ IntSpinBox::eventFilter(TQObject *o, TQEvent *e)
 			}
 		}
 	}
-	if ((TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(editor()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) || TQT_BASE_OBJECT(o->parent()) == TQT_BASE_OBJECT(this)) 
+	if ((o == editor() || o == this || o->parent() == this) 
 		&& e->type() == TQEvent::Wheel && static_cast<IntEdit*>(parentWidget())->isReadOnly())
 	{
 		return true; //avoid value changes for read-only widget
@@ -154,7 +154,7 @@ IntEdit::slotValueChanged(int)
 void
 IntEdit::updateSpinWidgets()
 {
-	TQObjectList *spinwidgets = queryList( TQSPINWIDGET_OBJECT_NAME_STRING, 0, false, true );
+	TQObjectList *spinwidgets = queryList( "TQSpinWidget", 0, false, true );
 	TQSpinWidget* spin = static_cast<TQSpinWidget*>(TQT_TQWIDGET(spinwidgets->first()));
 	if (spin) {
 		spin->setUpEnabled(!isReadOnly());
@@ -182,7 +182,7 @@ DoubleSpinBox::DoubleSpinBox (double lower, double upper, double step, double va
 	editor()->setAlignment(TQt::AlignLeft);
 	installEventFilter(editor());
 	installEventFilter(this);
-	TQObjectList *spinwidgets = queryList( TQSPINWIDGET_OBJECT_NAME_STRING, 0, false, true );
+	TQObjectList *spinwidgets = queryList( "TQSpinWidget", 0, false, true );
 	TQSpinWidget* spin = static_cast<TQSpinWidget*>(TQT_TQWIDGET(spinwidgets->first()));
 	if (spin)
 		spin->installEventFilter(this);
@@ -192,7 +192,7 @@ DoubleSpinBox::DoubleSpinBox (double lower, double upper, double step, double va
 bool
 DoubleSpinBox::eventFilter(TQObject *o, TQEvent *e)
 {
-	if(TQT_BASE_OBJECT(o) == editor())
+	if(o == editor())
 	{
 		if(e->type() == TQEvent::KeyPress)
 		{
@@ -204,7 +204,7 @@ DoubleSpinBox::eventFilter(TQObject *o, TQEvent *e)
 			}
 		}
 	}
-	if ((TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(editor()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) || TQT_BASE_OBJECT(o->parent()) == TQT_BASE_OBJECT(this)) 
+	if ((o == editor() || o == this || o->parent() == this) 
 		&& e->type() == TQEvent::Wheel && static_cast<IntEdit*>(parentWidget())->isReadOnly())
 	{
 		return true; //avoid value changes for read-only widget
@@ -307,7 +307,7 @@ DoubleEdit::slotValueChanged(double)
 void
 DoubleEdit::updateSpinWidgets()
 {
-	TQObjectList *spinwidgets = queryList( TQSPINWIDGET_OBJECT_NAME_STRING, 0, false, true );
+	TQObjectList *spinwidgets = queryList( "TQSpinWidget", 0, false, true );
 	TQSpinWidget* spin = static_cast<TQSpinWidget*>(TQT_TQWIDGET(spinwidgets->first()));
 	if (spin) {
 		spin->setUpEnabled(!isReadOnly());
