@@ -56,7 +56,7 @@ class CustomProperty;
 class Set;
 
 ///*! Helper function to create a value list from two string lists. */
-//KOPROPERTY_EXPORT TQMap<TQString, TQVariant> createValueListFromStringLists(
+//KOPROPERTY_EXPORT TQStringVariantMap createValueListFromStringLists(
 //	const TQStringList &keys, const TQStringList &values);
 
 /*! PropertyType.
@@ -66,7 +66,7 @@ enum PropertyType {
 	//standard supported TQVariant types
 	Auto = TQVariant::Invalid - 1,
 	Invalid = TQVariant::Invalid   /**<invalid property type*/,
-	Map = TQVariant::Map           /**<TQMap<TQString, TQVariant>*/,
+	Map = TQVariant::Map           /**<TQStringVariantMap*/,
 	List = TQVariant::List         /**<TQValueList<TQVariant>*/,
 	String = TQVariant::String     /**<string*/,
 	StringList = TQVariant::StringList  /**<string list*/,
