@@ -152,7 +152,7 @@ void
 Widget::setFocusWidget(TQWidget*focusProxy)
 {
 	if (focusProxy) {
-		if (focusProxy->focusPolicy() != TQ_NoFocus)
+		if (focusProxy->focusPolicy() != TQWidget::NoFocus)
 			setFocusProxy(focusProxy);
 		focusProxy->installEventFilter(this);
 	}
