@@ -23,9 +23,10 @@ KoFontTab::KoFontTab( uint fontListCriteria, TQWidget* parent, const char* name,
         : KoFontTabBase( parent, name, fl )
 {
     TQStringList list;
-    TDEFontChooser_local::getFontList(list, fontListCriteria);
+    TDEFontChooser::getFontList(list, fontListCriteria);
 
     characterFont->setFamilyList( list );
+    characterFont->setSampleBoxVisible(false);
     comparisonFont = characterFont->font();
     connect( characterFont, TQT_SIGNAL( fontSelected( const TQFont & ) ), this, TQT_SLOT( slotFontChanged( const TQFont & ) ) );
 }
