@@ -616,9 +616,7 @@ void KPagePreview2::drawContents( TQPainter* p )
         }
 
         switch ( align ) {
-#ifndef USE_QT4
             case TQt::AlignAuto:
-#endif // USE_QT4
             case TQt::AlignLeft:
                 __x = _x + 6;
                 break;
@@ -1278,9 +1276,7 @@ void KoParagAlignWidget::display( const KoParagLayout & lay )
 
     clearAligns();
     switch ( align ) {
-#ifndef USE_QT4
         case TQt::AlignAuto: // see KoView::setAlign
-#endif // USE_QT4
         case TQt::AlignLeft:
             rLeft->setChecked( true );
             break;
