@@ -1122,13 +1122,13 @@ TQPtrList<TDEAction> KoTextView::dataToolActionList(TDEInstance * instance, cons
 
     // Any tool that works on plain text is relevant
     TQValueList<KDataToolInfo> tools;
-    tools +=KDataToolInfo::query( TQSTRING_OBJECT_NAME_STRING, "text/plain", instance );
+    tools +=KDataToolInfo::query( "TQString", "text/plain", instance );
 
     // Add tools that work on a single word if that is the case
     if ( m_singleWord )
     {
         _singleWord = true;
-        tools += KDataToolInfo::query( TQSTRING_OBJECT_NAME_STRING, "application/x-singleword", instance );
+        tools += KDataToolInfo::query( "TQString", "application/x-singleword", instance );
     }
     // Maybe one day we'll have tools that use libkotext (or qt3's qrt), to act on formatted text
     tools += KDataToolInfo::query( "KoTextString", "application/x-qrichtext", instance );
@@ -1169,7 +1169,7 @@ void KoTextView::slotToolActivated( const KDataToolInfo & info, const TQString &
     if ( !info.mimeTypes().contains( mimetype ) )
     {
         mimetype = "text/plain";
-        datatype = TQSTRING_OBJECT_NAME_STRING;
+        datatype = "TQString";
     }
     // If unsupported (and if we have a single word indeed), try application/x-singleword
     if ( !info.mimeTypes().contains( mimetype ) && m_singleWord )
