@@ -62,5 +62,5 @@ Object::Ptr EventSignal::call(const TQString& /*name*/, TDESharedPtr<List> argum
     m_sender->tqt_emit(signalid, uo); // emit the signal
     delete [] uo;
 
-    return new Variant( TQVariant(true,0) );
+    return new Variant( TQVariant(true) );
 }
