@@ -62,7 +62,7 @@ Object::Ptr EventSlot::call(const TQString& /*name*/, List::Ptr arguments)
     m_receiver->tqt_invoke(slotid, uo); // invoke the slot
     delete [] uo;
 
-    return new Variant( TQVariant(true,0) );
+    return new Variant( TQVariant(true) );
 }
 
 /*
